@@ -16,9 +16,26 @@
 # along with this Python-EFL.  If not, see <http://www.gnu.org/licenses/>.
 
 # semver examples:
-# development: "1.12.99" ( 1, 12, 99 )
-# pre-release: "1.13.0-beta1" ( 1, 13, 0 )
-# release:     "1.13.0" ( 1, 13, 0 )
+# development: '1.12.99' ( 1, 12, 99 )
+# pre-release: '1.13.0-beta1' ( 1, 13, 0 )
+# release:     '1.13.0' ( 1, 13, 0 )
 
-__version__ = "1.23.0"
-__version_info__ = (1, 23, 0)
+__version__ = '1.25.0'
+__version_info__ = (1, 25, 0)
+
+
+__all__ = [
+    'dbus_mainloop',
+    'ecore',
+    'ecore_con',
+    'ecore_input',
+    'ecore_x',
+    'edje',
+    'edje_edit',
+    'elementary',
+    'emotion',
+    'eo',
+    'ethumb',
+    'evas',
+    'utils',
+]
